ngff_zarr.memory_usage - ngff-zarr
Description: Module Contents: Functions:,, memory_usage, Approximate array partition memory usage in bytes.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.memory_usage`

## Module Contents

### Functions

`memory_usage` | Approximate array partition memory usage in bytes.

### API

ngff_zarr.memory_usage.memory_usage(image: ngff_zarr.ngff_image.NgffImage, constrained_dims: Optional[Set[str]] = None) → int

  Approximate array partition memory usage in bytes.

  Assumes array will have the same memory usage resulting from an array chunk.